#!/bin/sh

#
# nouvelle.sh - Execute le script loftstory.sh toutes les 5 mn et affiche
# les nouvelles infos.
#
# Par defaut, nouvelle.sh affiche le contenu formate en 60 caracteres par
# ligne.
#
# Usage :
#
#     nouvelle.sh [NbCar] [-X]
#
# ou [NbCar] est le nombre de caracteres a afficher par ligne,
#    [-X] precise qu'il faut egalement afficher une fenetre a l'aide de
#         xmessage pour afficher la nouvelle info.
#
# Exemples :
#
#     xterm -geometry 165x51+0+0 -title "Les dernieres news du Loft" \
#     -bg yellow -xrm "*Page:0 1 1" -e ~/perso/loftstory/nouvelle.sh -X 100 &
#
# affiche une fenetre sur l'ecran virtuel en bas a droite, de fond jaune,
# avec 100 caracteres par ligne plus les nouvelles infos dans une fenetre.
#
# Requiere :
#
# loftstory.sh, xmessage, sleep.
#

DernierFic=/tmp/loftstory-news.$$
trap "rm -f $DernierFic ; exit 0"  0 2 3 6 9

cd `dirname $0`

X=""

while [ -n "$1" ]
do
    [ "$1"  = "-X" ] && X="X"
    [ "$1" != "-X" ] && MaxCarParLigne=$1 || MaxCarParLigne=60
    shift
done

loftstory ()
{
        ./loftstory.sh $MaxCarParLigne > $DernierFic
        DerniereNews=`grep "(.*:.*)" $DernierFic | head -n 1 | sed "s/.*(\(.*\)).*/\1/"`
}

DerniereNews=""

while true
do
    if [ -n "$DerniereNews" ]
    then
        loftstory
        if [ "$DerniereNewsE" != "$DerniereNews" ]
        then
            cat $DernierFic | \
            (
            echo
            echo "<news>"
            (
            while read ligne
            do
                echo "$ligne" | grep "$DerniereNews" && read && echo && break
            done

            while read ligne
            do
                [ -n "$ligne" ] && echo "$ligne" || break
            done 
            ) > $DernierFic.$$
            if [ -n "$X" ]
            then
                Titre="`head -n 1 $DernierFic.$$`"
                xmessage -title "$Titre" -center -file $DernierFic.$$ &
                sleep 3
            fi
            cat $DernierFic.$$
            rm -f $DernierFic.$$
        
            echo "</news>"
            )
        fi
    else # Premier lancement : aucune derniere news n'est definie.
        loftstory
        cat $DernierFic
    fi

    DerniereNewsE=$DerniereNews
    sleep 300
    rm -f $DernierFic
done

exit 0
